-- See all the customers who are going for 2nd application after the first application approval
DROP TABLE IF EXISTS onboarding.second_product_customers_npath;
CREATE TABLE onboarding.second_product_customers_npath
    DISTRIBUTE BY HASH(cmusno) 
    COMPRESS AS (
    SELECT *
    FROM NPATH(
    ON (SELECT *
    FROM onboarding.event_list_18_0_to_90_removed
    WHERE domain_type IN ('acq_chn', 'APPLICATION') AND event_desc NOT IN ('UnknownApp_', 'UnknownApp_Rejctd', 'UnknownApp_Apprvd'))
    PARTITION BY cmusno
    ORDER BY row_number
    MODE('NONOVERLAPPING')
    SYMBOLS(domain_type IN ('acq_chn') AS a,
    event_desc IN (
    'CCLimitInc_App_Apprvd',
    'ComLoan_App_Apprvd',
    'PreAprovdCC_Apprvd',
    'CorpLoan_App_Apprvd',
    'PreAprvdCCLmt_Apprvd',
    'PreAprvdLoan_Apprvd',
    'CC-Prm_App_Apprvd',
    'CC-Sup_App_Apprvd',
    'PerLoan_App_Apprvd') AS b,
    event_desc NOT IN (
    'CCLimitInc_App_Apprvd',
    'ComLoan_App_Apprvd',
    'PreAprovdCC_Apprvd',
    'CorpLoan_App_Apprvd',
    'PreAprvdCCLmt_Apprvd',
    'PreAprvdLoan_Apprvd',
    'CC-Prm_App_Apprvd',
    'CC-Sup_App_Apprvd',
    'PerLoan_App_Apprvd') AS c,
    event_desc IN (
    'CC-Sup_App_',
    'CC-Prm_App_',
    'CorpLoan_App_',
    'PerLoan_App_',
    'ComLoan_App_',
    'CCLimitInc_App_') AS d,
    event_desc NOT IN (
    'CC-Sup_App_',
    'CC-Prm_App_',
    'CorpLoan_App_',
    'PerLoan_App_',
    'ComLoan_App_',
    'CCLimitInc_App_') AS e
    )
    PATTERN('a.c*.b.e*.d')  -- Get all the customers where there is one application approval and customers are going for another application
    RESULT(ACCUMULATE(event_desc OF ANY(a, b, c, d, e)) AS path,
    FIRST(cmusno OF a) AS cmusno,
    COUNT(cmusno OF ANY(a, b, c, d, e)) AS lenPath,
    FIRST(event_date OF a) AS start_date,
    LAST(event_date OF ANY(d)) AS end_date)
    )
    );
GRANT ALL ON onboarding.second_product_customers_npath TO db_analytics;

--Accumulate paths
DROP TABLE IF EXISTS onboarding.freq_second_product_customers_npath;
CREATE TABLE onboarding.freq_second_product_customers_npath
    DISTRIBUTE BY HASH(path)
    COMPRESS AS (
    SELECT path, CAST(avg( CAST (end_date AS DATE) - CAST (start_date AS DATE) ) AS INTEGER) duration, lenPath, count(*) cnt
    FROM onboarding.second_product_customers_npath
    WHERE lenPath >= 2
    GROUP BY 1, lenPath
    );
GRANT ALL ON onboarding.freq_second_product_customers_npath TO db_analytics;

-- See all the events where datetime moved to end of the day due to missing time stamp
SELECT *
    FROM onboarding.event_list_18_rolled_0_to_90_removed
    WHERE domain_type = 'APPLICATION' AND event_desc NOT IN ('UnknownApp_', 'UnknownApp_Rejctd', 'UnknownApp_Apprvd')
    AND (CAST (event_date AS VARCHAR)) LIKE '%' || '23:59:59' || '%';   --38 events

SELECT count (DISTINCT cmusno)
    FROM onboarding.event_list_18_rolled_0_to_90_removed
    WHERE domain_type = 'APPLICATION'  AND event_desc NOT IN ('UnknownApp_', 'UnknownApp_Rejctd', 'UnknownApp_Apprvd')
    AND (CAST (event_date AS VARCHAR)) LIKE '%' || '23:59:59' || '%';  --33 events

-- All Paths count
SELECT count (*)
    FROM onboarding.second_product_customers_npath;   --34314 customers go for 2nd application

SELECT count (DISTINCT cmusno)
    FROM onboarding.second_product_customers_npath; --34314

-- See the Unique Paths
SELECT count (*)
    FROM onboarding.freq_second_product_customers_npath; -- 2247 Unique Paths

-- Single user paths
SELECT count(*)
    FROM onboarding.freq_second_product_customers_npath
    WHERE cnt = 1; --1454 individual paths

-- Customers having common paths equal to 5 or more
SELECT sum(cnt)
    FROM onboarding.freq_second_product_customers_npath
    WHERE cnt >= 5; --30813

--Customers where path length max path length is 8
SELECT sum(cnt)
    FROM onboarding.freq_second_product_customers_npath
    WHERE lenpath <= 8; --33020

SELECT *
    FROM onboarding.freq_second_product_customers_npath
    WHERE cnt >=2;

-- Visualization Code for AppCenter
--Tree visualisation code
--INSERT INTO app_center_visualizations  (json)
--SELECT json FROM Visualizer (
--    ON (select * from onboarding.freq_application_rate_npath where cnt >= 5) PARTITION BY 1 
--AsterFunction('npath')
--Title('acquisationchannel')
--VizType('tree')   
--);

--Sankey visualization Code
--INSERT INTO app_center_visualizations  (json) 
--SELECT json FROM Visualizer (
--   ON (select * from onboarding.freq_application_rate_npath where lenpath <= 8) PARTITION BY 1 
--AsterFunction('npath') 
--Title('acquisationchannel') 
--VizType('sankey')
--);